-- ============================================================================
-- ArtDefine_UnitInfos table    
-- ============================================================================
-- Mario
INSERT OR REPLACE INTO ArtDefine_UnitInfos 
        (Type,                                  DamageStates,   Formation)
SELECT  ('ART_DEF_UNIT_TRL_ITALIAN_PLUMBERS'),  DamageStates,   Formation
FROM ArtDefine_UnitInfos WHERE (Type = 'ART_DEF_UNIT__WARRIOR');

-- Trigger to ensure that the formation stays the same as the unit it replaces
-- (Warrior)
CREATE TRIGGER IF NOT EXISTS TRL_Mario_UpdateFormation
AFTER UPDATE OF Formation ON ArtDefine_UnitInfos
WHEN (OLD.Type = 'ART_DEF_UNIT__WARRIOR' OR OLD.Type = 'ART_DEF_UNIT_TRL_ITALIAN_PLUMBERS') AND ((SELECT Formation FROM ArtDefine_UnitInfos WHERE Type = 'ART_DEF_UNIT__WARRIOR') <> (SELECT Formation FROM ArtDefine_UnitInfos WHERE Type = 'ART_DEF_UNIT_TRL_ITALIAN_PLUMBERS'))
BEGIN
    UPDATE ArtDefine_UnitInfos
    SET Formation = (SELECT Formation FROM ArtDefine_UnitInfos WHERE Type = 'ART_DEF_UNIT__WARRIOR')
    WHERE (Type = 'ART_DEF_UNIT_TRL_ITALIAN_PLUMBERS');
END;

-- ============================================================================
-- ArtDefine_UnitInfoMemberInfos table
-- ============================================================================
-- Mario
INSERT OR REPLACE INTO ArtDefine_UnitInfoMemberInfos
        (UnitInfoType,                          UnitMemberInfoType,                             NumMembers)
VALUES  ('ART_DEF_UNIT_TRL_ITALIAN_PLUMBERS',   'ART_DEF_UNIT_MEMBER_TRL_MARIO',                1);

-- ============================================================================
-- ArtDefine_UnitMemberInfos table
-- ============================================================================
-- Mario
INSERT OR REPLACE INTO ArtDefine_UnitMemberInfos
        (Type,                              Scale,          ZOffset,    Domain, Model,                          MaterialTypeTag,    MaterialTypeSoundOverrideTag)
SELECT  ('ART_DEF_UNIT_MEMBER_TRL_MARIO'),  (Scale * 1.5),  ZOffset,    Domain, ('TRL_warrior_mario.fxsxml'),   'CLOTH',            'FLESH'
FROM ArtDefine_UnitMemberInfos WHERE (Type = 'ART_DEF_UNIT_MEMBER_WARRIOR');

-- Trigger to ensure the scale stays relative to the base unit (Warrior * 1.5)
CREATE TRIGGER IF NOT EXISTS TRL_Mario_UpdateScale
AFTER UPDATE OF Scale ON ArtDefine_UnitMemberInfos
WHEN (OLD.Type = 'ART_DEF_UNIT_MEMBER_WARRIOR' OR OLD.Type = 'ART_DEF_UNIT_MEMBER_TRL_MARIO') AND ((SELECT (Scale * 1.5) FROM ArtDefine_UnitMemberInfos WHERE Type = 'ART_DEF_UNIT_MEMBER_WARRIOR') <> (SELECT Scale FROM ArtDefine_UnitMemberInfos WHERE Type = 'ART_DEF_UNIT_MEMBER_TRL_MARIO'))
BEGIN
    UPDATE ArtDefine_UnitMemberInfos
    SET Scale = (SELECT (Scale * 1.5) FROM ArtDefine_UnitMemberInfos WHERE Type = 'ART_DEF_UNIT_MEMBER_WARRIOR')
    WHERE (Type = 'ART_DEF_UNIT_MEMBER_TRL_MARIO');
END;

-- ============================================================================
-- ArtDefine_UnitMemberCombats table
-- ============================================================================
-- Mario
INSERT OR REPLACE INTO ArtDefine_UnitMemberCombats
        (UnitMemberType,                    LastToDie, EnableActions, DisableActions, MoveRadius, ShortMoveRadius, ChargeRadius, AttackRadius, RangedAttackRadius, MoveRate, ShortMoveRate, TurnRateMin, TurnRateMax, TurnFacingRateMin, TurnFacingRateMax, RollRateMin, RollRateMax, PitchRateMin, PitchRateMax, LOSRadiusScale, TargetRadius, TargetHeight, HasShortRangedAttack, HasLongRangedAttack, HasLeftRightAttack, HasStationaryMelee, HasStationaryRangedAttack, HasRefaceAfterCombat, ReformBeforeCombat, HasIndependentWeaponFacing, HasOpponentTracking, HasCollisionAttack, AttackAltitude, AltitudeDecelerationDistance, OnlyTurnInMovementActions, RushAttackFormation)
SELECT  ('ART_DEF_UNIT_MEMBER_TRL_MARIO'),  LastToDie, EnableActions, DisableActions, MoveRadius, ShortMoveRadius, ChargeRadius, AttackRadius, RangedAttackRadius, MoveRate, ShortMoveRate, TurnRateMin, TurnRateMax, TurnFacingRateMin, TurnFacingRateMax, RollRateMin, RollRateMax, PitchRateMin, PitchRateMax, LOSRadiusScale, TargetRadius, TargetHeight, HasShortRangedAttack, HasLongRangedAttack, HasLeftRightAttack, HasStationaryMelee, HasStationaryRangedAttack, HasRefaceAfterCombat, ReformBeforeCombat, HasIndependentWeaponFacing, HasOpponentTracking, HasCollisionAttack, AttackAltitude, AltitudeDecelerationDistance, OnlyTurnInMovementActions, RushAttackFormation
FROM ArtDefine_UnitMemberCombats WHERE (UnitMemberType = 'ART_DEF_UNIT_MEMBER_WARRIOR');

-- ============================================================================
-- ArtDefine_UnitMemberCombatWeapons table
-- ============================================================================
-- Mario
INSERT OR REPLACE INTO ArtDefine_UnitMemberCombatWeapons
        (UnitMemberType,                    'Index', SubIndex, ID, VisKillStrengthMin, VisKillStrengthMax, ProjectileSpeed, ProjectileTurnRateMin, ProjectileTurnRateMax, HitEffect, HitEffectScale, HitRadius, ProjectileChildEffectScale, AreaDamageDelay, ContinuousFire, WaitForEffectCompletion, TargetGround, IsDropped, WeaponTypeTag, WeaponTypeSoundOverrideTag)
SELECT  'ART_DEF_UNIT_MEMBER_TRL_MARIO',    [Index], SubIndex, ID, VisKillStrengthMin, VisKillStrengthMax, ProjectileSpeed, ProjectileTurnRateMin, ProjectileTurnRateMax, HitEffect, HitEffectScale, HitRadius, ProjectileChildEffectScale, AreaDamageDelay, ContinuousFire, WaitForEffectCompletion, TargetGround, IsDropped, WeaponTypeTag, WeaponTypeSoundOverrideTag
FROM ArtDefine_UnitMemberCombatWeapons WHERE (UnitMemberType = 'ART_DEF_UNIT_MEMBER_WARRIOR');

-- ============================================================================
-- ArtDefine_StrategicView table
-- ============================================================================
INSERT OR REPLACE INTO ArtDefine_StrategicView
        (StrategicViewType,                     TileType,   Asset)
VALUES  ('ART_DEF_UNIT_TRL_ITALIAN_PLUMBERS',   'Unit',     'SV_TurtleShip.dds');
